@@ -30,4 +30,11 @@
 #   pragma warning(disable:5033)
 #endif
 
+#if defined(__clang__)
+#   pragma clang diagnostic ignored "-Wconversion"
+#   pragma clang diagnostic ignored "-Wsign-conversion"
+#   pragma clang diagnostic ignored "-Wdocumentation"
+#   pragma clang diagnostic ignored "-Wunused-but-set-variable"
+#endif
+
 #endif
